// {{{ copyright

/********************************************************************
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.option;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * This Option is intended to have its value displayed in a {@link
 * LabelOptionEdit LabelOptionEdit}.
 *
 * @author      Gregor Schmid
 * @since       0.99.0
 */
public class LabelOption
    extends StringOption
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger =
        new Logger ("de.qfs.lib.option.LabelOption");

    // }}}

    //----------------------------------------------------------------------
    // Constructor
    //----------------------------------------------------------------------
    // {{{ LabelOption(String)

    /**
     * Create an empty new LabelOption.
     *
     * @param   name    The name of the option.
     */
    public LabelOption (String name)
    {
        this (name, null);
    }

    // }}}
    // {{{ LabelOption(String,String)

    /**
     * Create a new LabelOption.
     *
     * @param   name    The name of the option.
     * @param   value   The label.
     */
    public LabelOption (String name, String value)
    {
        super(name, value);
        if (logger.level >= Log.MTD) {
            logger.log(Log.MTD, "LabelOption(String,String)",
                       logger.level < Log.MTDDETAIL ? "" :
                       "name: " + name + ", " +
                       "value: " + value);
        }
    }

    // }}}
}
