// {{{ copyright

/********************************************************************
 *
 * Copyright (C) 2000 Gregor Schmid, Quality First Software
 * All rights reserved
 *
 *******************************************************************/

// }}}

package de.qfs.lib.tree;

/**
 * Special Exception that signals a premature end of a tree traversal and
 * passes a result value back to the original caller.
 *
 * @author      Gregor Schmid
 * @since       0.98.1
 */
public class ReturnFromTraversalException
    extends RuntimeException
{
    // {{{ variables

    /**
     * The result of the traversal.
     */
    private Object result;

    // }}}

    //----------------------------------------------------------------------
    // Constructor
    //----------------------------------------------------------------------
    // {{{ ReturnFromTraversalException

    /**
     * Create a new ReturnFromTraversalException.
     *
     * @param   result  The result of the traversal.
     */
    public ReturnFromTraversalException(Object result)
    {
        super("Traversal terminated");
        this.result = result;
    }

    // }}}
    // {{{ getResult

    /**
     * Get the result of the traversal.
     *
     * @return  The result of the traversal.
     */
    public final Object getResult()
    {
        return result;
    }

    // }}}
}
