// {{{ copyright

/********************************************************************
 *
 * Copyright (C) 2000 Gregor Schmid, Quality First Software
 * All rights reserved
 *
 *******************************************************************/

// }}}

package de.qfs.lib.tree;

// {{{ imports

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * This interface must be implemented when traversing a tree with {@link
 * TreeUtil#traverse TreeUtil.traverse} or {@link TreeUtil#traverseFrom
 * TreeUtil.traverseFrom}.
 *
 * @author      Gregor Schmid
 * @since       0.98.1
 */
public interface TraversalCallback
{
    // {{{ nodeEntered

    /**
     * Notify the Callback that a node has been entered during traversal.
     *
     * @param traversal  The traversal for the node just entered.
     *
     * @return True if the children of the node should be traversed as
     *         well, false to ignore them.
     *
     * @throws ReturnFromTraversalException If the traversal should be
     * terminated prematurely.
     */
    public boolean nodeEntered(Traversal traversal)
        throws ReturnFromTraversalException;

    // }}}
    // {{{ nodeExited

    /**
     * Notify the Callback that a node has been exited during traversal.
     *
     * @param traversal  The traversal for the node just exited.
     *
     * @throws ReturnFromTraversalException If the traversal should be
     * terminated prematurely.
     */
    public void nodeExited(Traversal traversal)
        throws ReturnFromTraversalException;

    // }}}

}
