// {{{ copyright

/********************************************************************
 *
 * The contents of this file are subject to the Mozilla Public
 * License Version 1.1 (the "License"); you may not use this file
 * except in compliance with the License. You may obtain a copy of
 * the License at http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS
 * IS" basis, WITHOUT WARRANTY OF ANY KIND, either express or
 * implied. See the License for the specific language governing
 * rights and limitations under the License.
 *
 * The Original Code is qfs.de code.
 *
 * The Initial Developer of the Original Code is Gregor Schmid.
 * Portions created by Gregor Schmid are
 * Copyright (C) 2000 Quality First Software, Gregor Schmid.
 * All Rights Reserved.
 *
 * Contributor(s):
 *
 *******************************************************************/

// }}}

package de.qfs.lib.util;

// {{{ imports

import java.util.EventObject;

import de.qfs.lib.log.Log;
import de.qfs.lib.log.Logger;

// }}}

/**
 * Encapsulation of date received from a Stream or Reader.
 *
 * @author      Gregor Schmid
 * @since       0.99.0
 */
public class StreamEvent
    extends EventObject
{
    // {{{ variables

    /**
     * The Logger used for logging.
     */
    private final static Logger logger =
        new Logger ("de.qfs.lib.util.StreamEvent");

    /**
     * The newly arrived data.
     */
    private char[] data;

    // }}}

    //----------------------------------------------------------------------
    // Constructor
    //----------------------------------------------------------------------
    // {{{ StreamEvent(Object,char)

    /**
     * Create a new StreamEvent.
     *
     * @param   source  The source of the event.
     * @param   data   The newly arrived data.
     */
    public StreamEvent (Object source, char[] data)
    {
        super(source);
        this.data = data;
    }

    // }}}
    // {{{ StreamEvent(Object)

    /**
     * Create a new StreamEvent.
     *
     * @param   source  The source of the event.
     */
    public StreamEvent (Object source)
    {
        super(source);
    }

    // }}}

    // {{{ getData

    /**
     * Get the newly arrived data.
     *
     * @return      The newly arrived data.
     */
    public final char[] getData()
    {
        return data;
    }

    // }}}
}
